import chalk from 'chalk';

export interface Logger {
  info: (message: string, ...args: any[]) => void;
  warn: (message: string, ...args: any[]) => void;
  error: (message: string, ...args: any[]) => void;
  success: (message: string, ...args: any[]) => void;
  report: (stats: {total: number; success: number; skipped: number; failed: number}) => void;
  time: (label: string) => void;
  timeEnd: (label: string) => void;
  verbose: (message: string, ...args: any[]) => void;
}

const timers = new Map<string, number>();

export interface LoggerOptions {
  level?: 'verbose' | 'info';
}

export function createLogger(prefix: string, options: LoggerOptions = {}): Logger {
  const {level = 'info'} = options;
  const formatPrefix = () => chalk.cyan(`[${prefix}]`);
  const formatTime = (ms: number) => chalk.gray(`(${ms}ms)`);

  return {
    info: (message: string, ...args) => {
      console.log(`${formatPrefix()} ${message}`, ...args);
    },
    warn: (message: string, ...args) => {
      console.warn(`${formatPrefix()} ${chalk.yellow('warning')} ${message}`, ...args);
    },
    error: (message: string, ...args) => {
      console.error(`${formatPrefix()} ${chalk.red('error')} ${message}`, ...args);
    },
    success: (message: string, ...args) => {
      console.log(`${formatPrefix()} ${chalk.green('✓')} ${message}`, ...args);
    },
    report: stats => {
      const {total, success, skipped, failed} = stats;
      const hasIssues = failed > 0 || skipped > 0;

      console.log('\n' + formatPrefix() + ' ' + chalk.bold('Build Summary:'));

      // 使用表格样式展示统计
      const rows = [
        [`  ${chalk.bold('Total files:')}`, `${total}`],
        [`  ${chalk.bold('Processed:')}`, `${chalk.green(success)}`],
        [`  ${chalk.bold('Skipped:')}`, `${skipped > 0 ? chalk.yellow(skipped) : skipped}`],
        [`  ${chalk.bold('Failed:')}`, `${failed > 0 ? chalk.red(failed) : failed}`],
      ];

      rows.forEach(([label, value]) => {
        console.log(`${label.padEnd(20)}${value}`);
      });

      // 如果有问题，添加提示
      if (hasIssues) {
        console.log('\n' + formatPrefix() + ' ' + chalk.yellow('⚠️  Some files were not processed successfully'));
      } else {
        console.log('\n' + formatPrefix() + ' ' + chalk.green('✨ All files processed successfully'));
      }
      console.log(); // 空行
    },
    time: (label: string) => {
      timers.set(label, performance.now());
    },
    timeEnd: (label: string) => {
      const start = timers.get(label);
      if (start) {
        const duration = Math.round(performance.now() - start);
        console.log(`${formatPrefix()} ${label} ${formatTime(duration)}`);
        timers.delete(label);
      }
    },
    verbose: (message: string, ...args) => {
      if (level === 'verbose') {
        console.log(`${formatPrefix()} ${chalk.gray(message)}`, ...args);
      }
    },
  };
}
